@@ -1,3 +1,4 @@
+#!/usr/bin/env -S uv run --script
 # SPDX-License-Identifier: MIT
 
 # /// script
@@ -5,17 +6,16 @@
 # ///
 
 import argparse
-import os
-import os.path
+from pathlib import Path
 
 import nox
 
 nox.needs_version = ">=2025.2.9"
-nox.options.reuse_existing_virtualenvs = True
 nox.options.default_venv_backend = "uv|virtualenv"
 
-ALL_PYTHONS = nox.project.python_versions(nox.project.load_toml("pyproject.toml"))
-ALL_PYTHONS += ["3.14", "pypy-3.10"]
+PYPROJECT = nox.project.load_toml("pyproject.toml")
+ALL_PYTHONS = nox.project.python_versions(PYPROJECT)
+ALL_PYTHONS += ["pypy-3.11"]
 
 
 @nox.session(python="3.8")
@@ -23,9 +23,8 @@ def mypy(session: nox.Session) -> None:
     """
     Run a type checker.
     """
-    session.install(".", "mypy", "nox", "pytest")
-
-    session.run("mypy", "pyproject_metadata", "tests", "noxfile.py")
+    session.install("-e.", "mypy", "nox", "pytest")
+    session.run("mypy")
 
 
 @nox.session(python=ALL_PYTHONS)
@@ -33,12 +32,11 @@ def test(session: nox.Session) -> None:
     """
     Run the test suite.
     """
-    htmlcov_output = os.path.join(session.virtualenv.location, "htmlcov")
-    xmlcov_output = os.path.join(
-        session.virtualenv.location, f"coverage-{session.python}.xml"
-    )
+    htmlcov_output = Path(session.virtualenv.location) / "htmlcov"
+    xmlcov_output = Path(session.virtualenv.location) / f"coverage-{session.python}.xml"
 
-    session.install("-e.[test]")
+    test_grp = nox.project.dependency_groups(PYPROJECT, "test")
+    session.install("-e.", *test_grp)
 
     session.run(
         "pytest",
@@ -52,12 +50,34 @@ def test(session: nox.Session) -> None:
     )
 
 
+@nox.session(venv_backend="uv", default=False, python=ALL_PYTHONS)
+def minimums(session: nox.Session) -> None:
+    """
+    Check minimum requirements.
+    """
+    test_grp = nox.project.dependency_groups(PYPROJECT, "test")
+    session.install("-e.", "--resolution=lowest-direct", *test_grp, silent=False)
+
+    xmlcov_output = (
+        Path(session.virtualenv.location) / f"coverage-{session.python}-min.xml"
+    )
+
+    session.run(
+        "pytest",
+        "--cov",
+        f"--cov-report=xml:{xmlcov_output}",
+        "--cov-report=term-missing",
+        "--cov-context=test",
+        "tests/",
+        *session.posargs,
+    )
+
+
 @nox.session(default=False)
 def docs(session: nox.Session) -> None:
     """
     Build the docs. Use "--non-interactive" to avoid serving. Pass "-b linkcheck" to check links.
     """
-
     parser = argparse.ArgumentParser()
     parser.add_argument(
         "-b", dest="builder", default="html", help="Build target (default: html)"
@@ -66,7 +86,8 @@ def docs(session: nox.Session) -> None:
 
     serve = args.builder == "html" and session.interactive
     extra_installs = ["sphinx-autobuild"] if serve else []
-    session.install("-e.[docs]", *extra_installs)
+    docs_grp = nox.project.dependency_groups(PYPROJECT, "docs")
+    session.install("-e.", *docs_grp, *extra_installs)
 
     session.chdir("docs")
 
